@@ -9,7 +9,7 @@ from wafer.pages.models import Page
 
 class PageForm(ModelForm):
     def __init__(self, *args, **kwargs):
-        super(PageForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.helper = FormHelper()
         self.helper.include_media = False
         self.helper.add_input(Submit('submit', 'Submit'))
