@@ -19,14 +19,14 @@ class BlockTests(TestCase):
         """Create some days and check the results."""
         o1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         o2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 23, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 23, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
 
         self.assertEqual(ScheduleBlock.objects.count(), 2)
 
@@ -42,14 +42,14 @@ class BlockTests(TestCase):
         """Create 2 blocks that each cross midnight and check the results."""
         ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 23, 3, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 23, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 24, 3, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
 
         self.assertEqual(ScheduleBlock.objects.count(), 2)
 
@@ -62,82 +62,82 @@ class BlockTests(TestCase):
         """Test our blocks have start_time < end_time."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 11, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block1.clean)
         # Test across midnight
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 23, 1, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 23, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
 
     def test_changing_block(self):
         """Test that we can update block info and have correct validation behavior."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 27, 11, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 27, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         block1.clean()
         block1.save()
         # These should work
         block1.start_time = D.datetime(2013, 9, 27, 9, 0, 0,
-                                       tzinfo=timezone.utc)
+                                       tzinfo=D.timezone.utc)
         block1.clean()
         block1.save()
         block1.end_time = D.datetime(2013, 9, 27, 12, 0, 0,
-                                     tzinfo=timezone.utc)
+                                     tzinfo=D.timezone.utc)
         block1.clean()
         block1.save()
         # This should fail
         block1.start_time = D.datetime(2013, 9, 27, 15, 0, 0,
-                                       tzinfo=timezone.utc)
+                                       tzinfo=D.timezone.utc)
         self.assertRaises(ValidationError, block1.clean)
 
     def test_block_overlaps(self):
         """Test that we can't create overlapping blocks."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 1, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         # Test starting in the block
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 11, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 23, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
         # Test ending in the block
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 0, 30, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 11, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
         # Test across midnight
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 11, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 23, 23, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
         # Test included block
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 3, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 4, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
         # Test surrounding block
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 0, 15, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 23, 4, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, block2.clean)
 
 
@@ -147,25 +147,25 @@ class SlotTests(TestCase):
         """Test we can assign slots to a Block that spans only few hours."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 10, 20, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertEqual(slot1.get_block(), block1)
         self.assertEqual(slot1.get_duration(), {'hours': 1,
                                                 'minutes': 20})
         # Check end and start times
         slot2 = Slot(start_time=D.datetime(2013, 9, 22, 12, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot3 = Slot(start_time=D.datetime(2013, 9, 22, 18, 30, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertEqual(slot2.get_block(), block1)
         self.assertEqual(slot2.get_duration(), {'hours': 1,
                                                 'minutes': 0})
@@ -179,13 +179,13 @@ class SlotTests(TestCase):
            that spans midnight."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 23, 8, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 22, 23, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 23, 1, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertEqual(slot1.get_block(), block1)
         self.assertEqual(slot1.get_duration(), {'hours': 2,
                                                 'minutes': 0})
@@ -195,27 +195,27 @@ class SlotTests(TestCase):
         """Test that we can update slots and get the correct validation behaviour."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 26, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 26, 10, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 12, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot1.clean()
         slot1.save()
         # This should work
         slot1.start_time = D.datetime(2013, 9, 26, 9, 0, 0,
-                                      tzinfo=timezone.utc)
+                                      tzinfo=D.timezone.utc)
         slot1.clean()
         slot1.save()
         slot1.end_time = D.datetime(2013, 9, 26, 11, 0, 0,
-                                    tzinfo=timezone.utc)
+                                    tzinfo=D.timezone.utc)
         slot1.clean()
         slot1.save()
         # This should fail
         slot1.start_time = D.datetime(2013, 9, 26, 12, 0, 0,
-                                      tzinfo=timezone.utc)
+                                      tzinfo=D.timezone.utc)
         self.assertRaises(ValidationError, slot1.clean)
         slot1.delete()
         block1.delete()
@@ -224,58 +224,58 @@ class SlotTests(TestCase):
         """Test that we can't create overlapping slots."""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 26, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 26, 10, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 12, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot1.clean()
         slot1.save()
         # Start time is in the middle of slot1
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 11, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # End time is in the middle of slot2
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 11, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # Slot 2 totally encloses slot 1
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # Slot 2 totally included in slot 1
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 11, 30, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 12, 30, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # Slot 2 has the same times as slot 1
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 11, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # Check we don't raise errors on slots that touch as intended
         # slot 1 start time is slot 2's end time
         slot2 = Slot(start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 10, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot2.clean()
         slot2.save()
         # slot 1 end time is slot 2's start time
         slot3 = Slot(start_time=D.datetime(2013, 9, 26, 12, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot3.clean()
 
         slot1.delete()
@@ -288,32 +288,32 @@ class SlotTests(TestCase):
 
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 26, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 26, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 26, 10, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 26, 12, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot1.clean()
         slot1.save()
         slot2 = Slot(previous_slot=slot1,
                      end_time=D.datetime(2013, 9, 26, 13, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         slot2.clean()
         slot2.save()
 
         # Check that updating slot1's end_time to 12:30 works as expected
-        slot1.end_time = D.datetime(2013, 9, 26, 12, 30, 0, tzinfo=timezone.utc)
+        slot1.end_time = D.datetime(2013, 9, 26, 12, 30, 0, tzinfo=D.timezone.utc)
         slot1.clean()
         slot1.save()
 
         self.assertEqual(slot2.get_start_time(),
                          D.datetime(2013, 9, 26, 12, 30, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
 
         # Check that updating slot1's end_time to 13:30 fails, though
-        slot1.end_time = D.datetime(2013, 9, 26, 13, 30, 0, tzinfo=timezone.utc)
+        slot1.end_time = D.datetime(2013, 9, 26, 13, 30, 0, tzinfo=D.timezone.utc)
         self.assertRaises(ValidationError, slot1.clean)
 
     def test_invalid_slot(self):
@@ -321,24 +321,24 @@ class SlotTests(TestCase):
         # Same day
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         slot1 = Slot(start_time=D.datetime(2013, 9, 22, 11, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 10, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot1.clean)
         block2 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 24, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 25, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         # Different day,
         slot2 = Slot(start_time=D.datetime(2013, 9, 25, 1, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 24, 3, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
 
         block1.delete()
@@ -348,32 +348,32 @@ class SlotTests(TestCase):
         """Test that we can't create a slot outside the block's times"""
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 18, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         # Totally after
         slot1 = Slot(start_time=D.datetime(2013, 9, 22, 23, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 23, 1, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot1.clean)
         # Totally before
         slot2 = Slot(start_time=D.datetime(2013, 9, 21, 23, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 21, 1, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot2.clean)
         # Overlaps the end
         slot3 = Slot(start_time=D.datetime(2013, 9, 22, 17, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot3.clean)
         # Overlaps the start
         slot4 = Slot(start_time=D.datetime(2013, 9, 22, 7, 0, 0,
-                                           tzinfo=timezone.utc),
+                                           tzinfo=D.timezone.utc),
                      end_time=D.datetime(2013, 9, 22, 10, 0, 0,
-                                         tzinfo=timezone.utc))
+                                         tzinfo=D.timezone.utc))
         self.assertRaises(ValidationError, slot4.clean)
 
 
@@ -384,24 +384,24 @@ class LastUpdateTests(TestCase):
         timezone.activate('UTC')
         block1 = ScheduleBlock.objects.create(
                 start_time=D.datetime(2013, 9, 22, 9, 0, 0,
-                                      tzinfo=timezone.utc),
+                                      tzinfo=D.timezone.utc),
                 end_time=D.datetime(2013, 9, 22, 19, 0, 0,
-                                    tzinfo=timezone.utc))
+                                    tzinfo=D.timezone.utc))
         venue1 = Venue.objects.create(order=1, name='Venue 1')
         venue2 = Venue.objects.create(order=2, name='Venue 2')
         venue1.blocks.add(block1)
         venue2.blocks.add(block1)
 
         start1 = D.datetime(2013, 9, 22, 10, 0, 0,
-                            tzinfo=timezone.utc)
+                            tzinfo=D.timezone.utc)
         start2 = D.datetime(2013, 9, 22, 11, 0, 0,
-                            tzinfo=timezone.utc)
+                            tzinfo=D.timezone.utc)
         start3 = D.datetime(2013, 9, 22, 12, 0, 0,
-                            tzinfo=timezone.utc)
+                            tzinfo=D.timezone.utc)
         start4 = D.datetime(2013, 9, 22, 13, 0, 0,
-                            tzinfo=timezone.utc)
+                            tzinfo=D.timezone.utc)
         start5 = D.datetime(2013, 9, 22, 14, 0, 0,
-                            tzinfo=timezone.utc)
+                            tzinfo=D.timezone.utc)
         self.slots = []
         self.slots.append(Slot.objects.create(start_time=start1,
                                               end_time=start2))
